/*
 *      launch_codes.c
 *      
 *      Copyright 2011 Brian Starkey <stark3y[AT]gmail[DOT]com>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 *
 *
 *      libcurses program which displays random 5 digit numbers in a way
 *      reminiscent of code displays in Hollywood movies.
 * 
 */
 
#include <ncurses.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

WINDOW *create_newwin(int height, int width, int starty, int startx);

WINDOW *led;

char screen_offset = 0;

void destroy_win(WINDOW *local_win);

int main(int argc, char *argv[])
{	
	int maxx, maxy;
	
	initscr();			/* Start curses mode 		*/
	cbreak();			/* Line buffering disabled */
	keypad(stdscr, TRUE);		/* I need that nifty F1 	*/
	noecho();
	start_color();
	getmaxyx(stdscr,maxy,maxx);
	
	led = create_newwin(3, 7, (maxy/2)-1, (maxx/2)-4);
	init_pair(1, COLOR_RED, COLOR_BLACK);
	wattron(led, COLOR_PAIR(1));
	wrefresh(led);
	refresh();

	for (;;) {
		unsigned int code_numbers[5], i;
		unsigned char display_numbers[5];
		for (i = 0; i < 5; i++) {
			code_numbers[i] = (int)(rand()%800)+200;
			display_numbers[i] = (char)(rand()%10);
		}
		for (i = 0; i < 1000; i++) {
			unsigned char k;
			wmove(led, 1, 1);
			for (k = 0; k < 5; k++) {
				if (i < code_numbers[k]) {
					display_numbers[k]++;
					display_numbers[k] %= 10;
				}
				wprintw(led, "%1i", display_numbers[k]);
			}
			wrefresh(led);
			usleep(10000);			
		}
		usleep(3000000);
	}
	endwin();			/* End curses mode		  */
	return 0;
}


WINDOW *create_newwin(int height, int width, int starty, int startx)
{	WINDOW *local_win;
	local_win = newwin(height, width, starty, startx);
	box(local_win, 0 , 0);		/* 0, 0 gives default characters 
					 * for the vertical and horizontal
					 * lines			*/
	wrefresh(local_win);		/* Show that box 		*/

	return local_win;
}

void destroy_win(WINDOW *local_win)
{	
	/* box(local_win, ' ', ' '); : This won't produce the desired
	 * result of erasing the window. It will leave it's four corners 
	 * and so an ugly remnant of window. 
	 */
	wborder(local_win, ' ', ' ', ' ',' ',' ',' ',' ',' ');
	/* The parameters taken are 
	 * 1. win: the window on which to operate
	 * 2. ls: character to be used for the left side of the window 
	 * 3. rs: character to be used for the right side of the window 
	 * 4. ts: character to be used for the top side of the window 
	 * 5. bs: character to be used for the bottom side of the window 
	 * 6. tl: character to be used for the top left corner of the window 
	 * 7. tr: character to be used for the top right corner of the window 
	 * 8. bl: character to be used for the bottom left corner of the window 
	 * 9. br: character to be used for the bottom right corner of the window
	 */
	wrefresh(local_win);
	delwin(local_win);
}
